package hdm.mi.growbros.service;

import hdm.mi.growbros.models.plant.Plant;
import hdm.mi.growbros.repositories.PlantRepository;
import lombok.RequiredArgsConstructor;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Random;

@Service
@RequiredArgsConstructor
public class PlantsService {
    private final static Logger log = LoggerFactory.getLogger(PlantsService.class);

    private final PlantRepository plantRepository;

    public Collection<Plant> getPlants(int pageNumber, int pageSize) {
        final Pageable page = PageRequest.of(pageNumber, pageSize);
        return plantRepository.findAll(page).getContent();
    }

    public Collection<Plant> getRandomPlants(int numberOfPlants) {
        List<Plant> allPlants = plantRepository.findAll(); // Annahme: findAll gibt alle Pflanzen zurück

        if (allPlants.size() <= numberOfPlants) {
            return allPlants;
        } else {
            List<Plant> randomPlants = new ArrayList<>();
            Random random = new Random();

            while (randomPlants.size() < numberOfPlants) {
                Plant randomPlant = allPlants.get(random.nextInt(allPlants.size()));

                if (!randomPlants.contains(randomPlant)) {
                    randomPlants.add(randomPlant);
                }
            }
            return randomPlants;
        }
    }

    public void createPlant(Plant plant) {
        log.info("Saving plant '{}' to repository.", plant.getName());
        plantRepository.save(plant);
    }

    public List<Plant> search(String search) {
        return plantRepository.findByNameIsLike(search);
    }
}
